import React from 'react';
import PropTypes from 'prop-types';
import gql from 'graphql-tag';

import { WebsiteScheduledContent } from '@base-cms/nextjs-web/queries';
import { Card } from '../../core';
import { CardBodyD, ListGroupA } from '../../content';

const fragment = gql`
  fragment ContentBlockHeroStyleB on Content {
    ...ContentListGroupStyleA
    ...ContentCardBodyStyleD
  }
  ${CardBodyD.fragments.content}
  ${ListGroupA.fragments.content}
`;

const propTypes = {
  // @todo These should be placed here by a HOC.
  query: PropTypes.shape({
    after: PropTypes.string,
    children: PropTypes.func,
    excludeContentIds: PropTypes.arrayOf(PropTypes.string),
    excludeContentTypes: PropTypes.arrayOf(PropTypes.string),
    limit: PropTypes.number,
    includeContentTypes: PropTypes.arrayOf(PropTypes.string),
    requiresImage: PropTypes.bool,
    sectionBubbling: PropTypes.bool,
    sectionId: PropTypes.number.isRequired,
    optionId: PropTypes.number,
  }),
};

const defaultProps = {
  query: {},
};

const BlockHeroB = ({
  query,
  ...attrs
}) => {
  const props = { ...query, fragment };
  return (
    <WebsiteScheduledContent {...props}>
      {({ loading, error, items }) => {
        if (loading) return <span>Loading...</span>;
        if (error) {
          return (
            <span>
              Error
              {' '}
              {error.message}
            </span>
          );
        }
        const content = items[0] || {};
        const nodes = items.slice(1) || [];
        return (
          <div className="row">
            <div className="col-lg-7 col-xl-8">
              <Card>
                <CardBodyD content={content} {...attrs} />
              </Card>
            </div>
            <div className="col-lg-5 col-xl-4">
              <Card>
                <ListGroupA flush nodes={nodes} {...attrs} />
              </Card>
            </div>
          </div>
        );
      }}
    </WebsiteScheduledContent>
  );
};

BlockHeroB.displayName = 'WebsiteScheduledContent/Blocks/HeroB';
BlockHeroB.propTypes = propTypes;
BlockHeroB.defaultProps = defaultProps;

export default BlockHeroB;
